"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.up = void 0;

var _fs = require("fs");

var _path = require("path");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const initalize = async sql => {
  try {
    await sql`SELECT 'migrations'::REGCLASS;`;
  } catch (err) {
    await sql`
      CREATE TABLE IF NOT EXISTS migrations (
        id SERIAL PRIMARY KEY,
        name TEXT NOT NULL,
        created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
      );
    `;
  }
};

const executedMigrations = async sql => {
  const rows = await sql`SELECT name FROM migrations ORDER BY id ASC`;
  return rows.map(row => row.name);
};

const definedMigrations = async () => {
  const files = (0, _fs.readdirSync)(__dirname).filter(name => name.match(/^[0-9]{3}\-/)).sort();
  const migrations = await Promise.all(files.map(async file => Object.assign(await Promise.resolve(`${(0, _path.join)(__dirname, file)}`).then(s => _interopRequireWildcard(require(s))), {
    name: file
  })));
  return migrations;
};

const up = async sql => {
  await initalize(sql);
  return await sql.begin(async sql => {
    const executed = await executedMigrations(sql);
    const migrations = await definedMigrations();

    if (JSON.stringify(executed) !== JSON.stringify(migrations.slice(0, executed.length).map(migration => migration.name))) {
      throw new Error('migration seems broken. please check if migrations file and exists is same');
    }

    const toExecute = migrations.slice(executed.length);

    for (const migration of toExecute) {
      await migration.up(sql);
      await sql`INSERT INTO migrations (name) VALUES (${migration.name})`;
    }

    return toExecute.map(migration => migration.name);
  });
};

exports.up = up;