"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PGDatabase = void 0;

var _util = require("util");

var _database = require("./database");

var _token = require("./services/token");

var _localPackage = require("./services/local-package");

var _verdaccioSecret = require("./services/verdaccio-secret");

var _pgFs = require("./pg-fs");

var _package = require("./services/package");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class PGDatabase {
  constructor(config, options) {
    _defineProperty(this, "logger", void 0);

    _defineProperty(this, "config", void 0);

    _defineProperty(this, "locked", void 0);

    _defineProperty(this, "database", void 0);

    _defineProperty(this, "token", void 0);

    _defineProperty(this, "localPackage", void 0);

    _defineProperty(this, "verdaccioSecret", void 0);

    _defineProperty(this, "getSecret", () => this.verdaccioSecret.get());

    _defineProperty(this, "setSecret", secret => this.verdaccioSecret.set(secret));

    _defineProperty(this, "add", (0, _util.callbackify)(name => this.localPackage.add(name)));

    _defineProperty(this, "search", (onPackage, onEnd) => {
      _package.PackageService.search(this.database, onPackage, onEnd);
    });

    _defineProperty(this, "remove", (0, _util.callbackify)(name => this.localPackage.remove(name)));

    _defineProperty(this, "get", (0, _util.callbackify)(() => this.localPackage.get()));

    _defineProperty(this, "getPackageStorage", name => {
      const access = this.config.getMatchedPackagesSpec(name); // eslint-disable-next-line @typescript-eslint/prefer-optional-chain

      const storage = access && access.storage || this.config.storage || 'default';
      return new _pgFs.PGPackageManager(this.database, this.logger, storage, name);
    });

    _defineProperty(this, "clean", (0, _util.callbackify)(() => this.localPackage.clean()));

    _defineProperty(this, "saveToken", token => this.token.save(token));

    _defineProperty(this, "deleteToken", (user, token) => this.token.deleteToken(user, token));

    _defineProperty(this, "readTokens", filter => this.token.readToken(filter));

    this.locked = false;
    this.logger = options.logger;

    if (!config) {
      throw new Error('[pg-storage] missing config. Add `store.pg-storage` to your config file');
    }

    this.config = Object.assign(config, config.store['pg-storage']);
    this.config.url = process.env.POSTGRES_URL || this.config.url;

    if (!this.config.url) {
      throw new Error('[pg-storage] missing config. Add `store.pg-storage.url` to your config file or use environtment POSTGRES_URL');
    }

    this.logger.debug({
      config: JSON.stringify(this.config, null, 4)
    }, 'pg: configuration: @{config}');
    this.database = new _database.Database(this.config.url);
    this.token = new _token.TokenService(this.database, this.logger);
    this.localPackage = new _localPackage.LocalPackagesService(this.database, this.logger);
    this.verdaccioSecret = new _verdaccioSecret.VerdaccioSecretService(this.database, this.logger);
  }

}

exports.PGDatabase = PGDatabase;