"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PGPackageManager = void 0;

var _util = require("util");

var _streams = require("@verdaccio/streams");

var _package = require("./services/package");

var _tarball = require("./services/tarball");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const noop = () => {// Make linter happy
};

class PGPackageManager {
  constructor(database, logger, storage, _name) {
    _defineProperty(this, "logger", void 0);

    _defineProperty(this, "package", void 0);

    _defineProperty(this, "tarball", void 0);

    _defineProperty(this, "updatePackage", (0, _util.callbackify)((name, updateHandler, onWrite, transformPackage) => this.package.update(name, updateHandler, onWrite, transformPackage)));

    _defineProperty(this, "deletePackage", (0, _util.callbackify)(async name => {
      if (name === 'package.json') {
        await this.package.delete();
      } else {
        await this.tarball.delete(name);
      }
    }));

    _defineProperty(this, "removePackage", (0, _util.callbackify)(async () => {
      await this.package.delete();
      await this.tarball.remove();
    }));

    _defineProperty(this, "createPackage", (0, _util.callbackify)((name, value) => this.package.create(name, value)));

    _defineProperty(this, "savePackage", (0, _util.callbackify)((name, value) => this.package.save(name, value)));

    _defineProperty(this, "readPackage", (0, _util.callbackify)(name => this.package.read(name)));

    _defineProperty(this, "writeTarball", name => {
      const upload = new _streams.UploadTarball({});
      let ended = false;
      upload.on('end', () => {
        ended = true;
      });
      this.tarball.write(name, upload);

      upload.done = () => {
        const onEnd = () => {
          upload.emit('success');
        };

        if (ended) {
          onEnd();
        } else {
          upload.on('end', onEnd);
        }
      };

      upload.abort = noop;
      return upload;
    });

    _defineProperty(this, "readTarball", name => {
      const read = new _streams.ReadTarball({});
      this.tarball.read(name, read);
      return read;
    });

    this.logger = logger;
    this.package = new _package.PackageService(database, logger, storage, _name);
    this.tarball = new _tarball.TarballService(database, logger, storage, _name);
  }

}

exports.PGPackageManager = PGPackageManager;