"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LocalPackagesService = void 0;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint-disable no-invalid-this */
class LocalPackagesService {
  constructor(database, logger) {
    _defineProperty(this, "database", void 0);

    _defineProperty(this, "logger", void 0);

    _defineProperty(this, "add", async name => {
      this.logger.debug({
        name
      }, '[pg-storage/local-package]: add private package @{name}');
      const sql = await this.database.sql();
      await sql`
    INSERT INTO local_packages
      (name, created, updated)
    VALUES
      (${name}, NOW(), NOW())
      ON CONFLICT (name) DO UPDATE SET updated = NOW()
  `;
      this.logger.debug({
        name
      }, '[pg-storage/local-package]: the private package @{name} has been added');
    });

    _defineProperty(this, "remove", async name => {
      this.logger.debug({
        name
      }, '[pg-storage/local-package]: remove private package @{name}');
      const sql = await this.database.sql();
      await sql`
      DELETE FROM local_packages WHERE name = ${name}
    `;
      this.logger.debug({
        name
      }, '[pg-storage/local-package]: package @{name} has been removed');
    });

    _defineProperty(this, "get", async () => {
      this.logger.debug('[pg-storage/local-package]: get full list of private package');
      const sql = await this.database.sql();
      const rows = await sql`
      SELECT name FROM local_packages
    `;
      this.logger.trace({
        totalItems: rows.length
      }, '[pg-storage/local-package]: full list of packages (@{totalItems}) has been fetched');
      return rows.map(row => row.name);
    });

    _defineProperty(this, "clean", async () => {
      const sql = await this.database.sql();
      await sql`
      TRUNCATE TABLE local_packages
    `;
    });

    this.database = database;
    this.logger = logger;
  }

}

exports.LocalPackagesService = LocalPackagesService;