"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PackageService = void 0;

var _util = require("util");

var VerdaccioError = _interopRequireWildcard(require("@verdaccio/commons-api"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class PackageService {
  constructor(database, logger, storage, _name) {
    _defineProperty(this, "database", void 0);

    _defineProperty(this, "logger", void 0);

    _defineProperty(this, "storage", void 0);

    _defineProperty(this, "name", void 0);

    _defineProperty(this, "create", async (name, json) => {
      this.logger.debug({
        name
      }, '[pg-storage/package] create package @{name}');
      await this.save(name, json);
      this.logger.debug({
        name
      }, '[pg-storage/package] package @{name} created');
    });

    _defineProperty(this, "save", async (name, json) => {
      this.logger.debug({
        name
      }, '[pg-storage/package] save package @{name}');
      const sql = await this.database.sql();
      await sql`
      INSERT INTO packages 
        (storage, name, json)
      VALUES
        (${this.storage}, ${name}, ${sql.json(json)})
      ON CONFLICT (storage, name)
      DO UPDATE
      SET 
        json = ${sql.json(json)},
        updated = NOW()
    `;
      this.logger.debug({
        name
      }, '[pg-storage/package] package @{name} saved');
    });

    _defineProperty(this, "update", async (name, updateHandler, onWrite, transformPackage) => {
      this.logger.debug({
        name
      }, '[pg-storage/package] update package @{name}');
      const updateHandlerAsync = (0, _util.promisify)(updateHandler);
      const onWriteAsync = (0, _util.promisify)(onWrite);
      const pkg = await this.read(name);
      await updateHandlerAsync(pkg);
      const transformed = transformPackage(pkg);
      await onWriteAsync(name, transformed);
      this.logger.debug({
        name
      }, '[pg-storage/package] package @{name} updated');
    });

    _defineProperty(this, "read", async name => {
      this.logger.debug({
        name
      }, '[pg-storage/package] read package @{name}');
      const sql = await this.database.sql();
      const [pkg] = await sql`
      SELECT json FROM packages WHERE storage = ${this.storage} AND name = ${name}
    `;

      if (!pkg) {
        throw VerdaccioError.getNotFound();
      }

      this.logger.debug({
        name
      }, '[pg-storage/package] package @{name} read');
      return pkg.json;
    });

    _defineProperty(this, "delete", async () => {
      this.logger.debug({
        name: this.name
      }, '[pg-storage/package] delete package @{name}');
      const sql = await this.database.sql();
      await sql`DELETE FROM packages WHERE storage = ${this.storage} AND name = ${this.name}`;
      this.logger.debug({
        name: this.name
      }, '[pg-storage/package] deleted package @{name}');
    });

    this.database = database;
    this.logger = logger;
    this.storage = storage;
    this.name = _name;
  }

}

exports.PackageService = PackageService;

_defineProperty(PackageService, "search", async (database, onPackage, onEnd) => {
  const sql = await database.sql();
  await sql`SELECT json, updated FROM packages`.stream(({
    json,
    updated
  }) => {
    return onPackage({
      name: json.name,
      path: json.name,
      time: updated.getTime()
    });
  });
  onEnd();
});